@@ -6,18 +6,11 @@
 #ifndef __KDEVPART_RUBYSUPPORT_H__
 #define __KDEVPART_RUBYSUPPORT_H__
 
-
-#include <qguardedptr.h>
-
-#include <kprocess.h>
-#include <kdialogbase.h>
-
-#include "kdevplugin.h"
 #include "kdevlanguagesupport.h"
 
-
-class RubySupportWidget;
-
+class KDialogBase;
+class QPopupMenu;
+class Context;
 
 class RubySupportPart : public KDevLanguageSupport
 {
@@ -50,6 +43,7 @@ private slots:
 private:
     void startApplication(const QString &program);
     QString interpreter();
+    QString shell();
     QString mainProgram();
     QString programArgs();
     QString characterCoding();
@@ -60,6 +54,8 @@ private:
     QMap<KInterfaceDesigner::DesignerType, KDevDesignerIntegration*> m_designers;
     
     QString m_contextFileName;
+    QCString m_savedShell;
+    QCString m_shell;
 
 };
 
