@@ -36,7 +36,7 @@ private slots:
     void projectConfigWidget(KDialogBase *dlg);
     void projectOpened();
     void projectClosed();
-    void savedFile(const QString &fileName);
+    void savedFile(const KURL &fileName);
     void addedFilesToProject(const QStringList &fileList);
     void removedFilesFromProject(const QStringList &fileList);
     void parse();
