@@ -13,6 +13,7 @@
 
 #include <qstylesheet.h>
 
+#include <kdebug.h>
 #include <klocale.h>
 
 #include "ktexteditor/cursorinterface.h"
@@ -66,10 +67,19 @@ QString MakeItem::text( EOutputLevel )
 
 QString MakeItem::formattedText( EOutputLevel level, bool bright_bg )
 {
-    if (m_text.isEmpty())
-	return "<br>";
-    return QString("<code>").append( icon() ).append("<font color=\"").append( color( bright_bg) ).append(
-		"\">").append( text(level) ).append("</font></code>").append( br() );
+  QString txt = text(level);
+	if (txt.isEmpty())
+		return "<br>";
+	if ( level == eFull )
+	{
+		return txt;
+	}
+	else
+	{
+		return QString("<code>")
+        .append( icon() ).append("<font color=\"").append( color( bright_bg) ).append("\">")
+        .append( txt ).append("</font></code>").append( br() );
+	}
 }
 
 QString MakeItem::br()
@@ -116,15 +126,18 @@ ExitStatusItem::ExitStatusItem( bool normalExit, int exitStatus )
 	: m_normalExit( normalExit )
 	, m_exitStatus( exitStatus )
 {
+//	kdDebug() << "ExitStatusItem: normalExit=" << normalExit << "; exitStatus=" << exitStatus << endl;
+	m_text = i18n("*** Compilation aborted ***");
+	if ( m_normalExit )
+		if (m_exitStatus )
+			m_text = i18n("*** Exited with status: %1 ***").arg( m_exitStatus );
+        	else
+			m_text = i18n("*** Success ***");
 }
 
 QString ExitStatusItem::text( EOutputLevel )
 {
-	if ( m_normalExit && m_exitStatus )
-		return i18n("*** Exited with status: %1 ***").arg( m_exitStatus );
-	if ( m_normalExit )
-		return i18n("*** Success ***");
-	return i18n("*** Compilation aborted ***");
+	return m_text;	
 }
 
 bool DirectoryItem::m_showDirectoryMessages = true;
