@@ -162,17 +162,13 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 {
 	updateSettingsFromConfig();
 
-/*	if ( m_compilerOutputLevel == eFull )
-	{
-		setTextFormat( Qt::LogText );
-	}
-	else
-	{*/
-		setTextFormat( Qt::RichText );
-//	}
+	setTextFormat( Qt::RichText );
 	
 	if ( m_bLineWrapping )
 		setWordWrap(WidgetWidth);
+	else
+		setWordWrap(NoWrap);
+
 	setWrapPolicy(Anywhere);
 	setReadOnly(true);
 	setMimeSourceFactory(new QMimeSourceFactory);
@@ -819,7 +815,8 @@ void MakeWidget::updateSettingsFromConfig()
 {
 	KConfig *pConfig = kapp->config();
 	pConfig->setGroup("General Options");
-	setFont(pConfig->readFontEntry("Application Font"));
+	QFont outputFont = pConfig->readFontEntry("OutputViewFont");
+	setFont(outputFont);
 	pConfig->setGroup("MakeOutputView");
 	m_bLineWrapping = pConfig->readBoolEntry("LineWrapping", true);
 	m_compilerOutputLevel = (EOutputLevel) pConfig->readNumEntry("CompilerOutputLevel", (int) eShort);
